=============================
Silota
=============================

.. image:: https://travis-ci.org/silota/silota-python.png?branch=master
        :target: https://travis-ci.org/silota/silota-python


Python client for Silota API_.

Installation
-------------

.. code-block :: bash

    $ pip install silota

Usage
-------------

View the quick start at http://www.silota.com/docs/client/quickstart/python/.


Tests
-------------

To run tests, you'll need to install the additional packages in ``requirements-test.txt``. Then,

.. code-block :: bash

    $ nosetests


Contributing
-------------

1. Create a fork
2. Create a feature branch (``git checkout -b my-new-feature``)
3. Write code and tests
4. Commit your changes (``git commit -am 'New feature``)
5. Ensure all tests still pass (``nosetests``)
6. Push to branch (``git push origin my-new-feature``)
7. Open pull request

Credits
-------------

Heavily inspired by https://github.com/heroku/heroku.py.


.. _API: http://www.silota.com/docs/api/


